@@ -200,9 +200,6 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
             self.initial_auto_launch = 0
             self.combobox_other_updates.set_sensitive(False)
 
-        self.sp_settings = Gio.Settings.new('com.ubuntu.SoftwareProperties')
-        self.info_bar_ubuntu_pro.set_visible(self.sp_settings.get_boolean("ubuntu-pro-banner-visible"))
-
         # get the dbus backend
         bus = dbus.SystemBus()
         proxy = bus.get_object("com.ubuntu.SoftwareProperties", "/")
@@ -429,11 +426,8 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
                 # gives software properties dialogs a chance to interact about
                 # renewals if needed.
                 try:
-                        # Ignore timezone to simplify formatting python < 3.7
-                        # 3.7 has datetime.fromisoformat()
-                        dt, _sep, _tz = status.get("expires", "").partition("+")
                         eol_date = datetime.datetime.strptime(
-                            dt, "%Y-%m-%dT%H:%M:%S"
+                                status.get("expires"), "%Y-%m-%dT%H:%M:%S"
                         ).date()
                 except ValueError:
                         print("Unable to determine UA contract expiry")
@@ -1222,9 +1216,8 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
             self.progress_bar.set_fraction(prog_value / 100.0)
 
     def on_driver_changes_finish(self, source, result, installs_pending):
-        results = None
         try:
-            results = self.pk_task.generic_finish(result)
+            self.pk_task.generic_finish(result)
         except Exception as e:
             self.on_driver_changes_revert()
             error(self.window_main, _("Error while applying changes"), str(e))
@@ -1646,6 +1639,3 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
     def init_livepatch(self):
         self.livepatch_page = LivepatchPage(self)
 
-    def on_info_bar_ubuntu_pro_response(self, info_bar, response_id):
-        self.sp_settings.set_boolean("ubuntu-pro-banner-visible", False)
-        info_bar.hide()
